@@ -10,7 +10,7 @@ mod admin_interface_config;
 mod dpki_config;
 #[allow(missing_docs)]
 mod error;
-mod passphrase_service_config;
+mod keystore_config;
 pub mod paths;
 //mod logger_config;
 //mod signal_config;
@@ -20,10 +20,9 @@ pub use super::*;
 pub use dpki_config::DpkiConfig;
 //pub use logger_config::LoggerConfig;
 pub use error::*;
-pub use passphrase_service_config::PassphraseServiceConfig;
+pub use keystore_config::KeystoreConfig;
 //pub use signal_config::SignalConfig;
 use std::path::Path;
-use std::path::PathBuf;
 
 // TODO change types from "stringly typed" to Url2
 /// All the config information for the conductor
@@ -33,26 +32,14 @@ pub struct ConductorConfig {
     /// If omitted, chooses a default path.
     pub environment_path: EnvironmentRootPath,
 
-    /// Enabling this will use a test keystore instead of lair.
-    /// This generates publicly accessible private keys.
-    /// DO NOT USE THIS IN PRODUCTION!
+    /// Define how Holochain conductor will connect to a keystore.
     #[serde(default)]
-    pub use_dangerous_test_keystore: bool,
+    pub keystore: KeystoreConfig,
 
     /// Optional DPKI configuration if conductor is using a DPKI app to initalize and manage
     /// keys for new instances
     pub dpki: Option<DpkiConfig>,
 
-    /// Optional path for keystore directory.  If not specified will use the default provided
-    /// by the [ConfigBuilder]()https://docs.rs/lair_keystore_api/0.0.1-alpha.4/lair_keystore_api/struct.ConfigBuilder.html)
-    pub keystore_path: Option<PathBuf>,
-
-    /// Configure how the conductor should prompt the user for the passphrase to lock/unlock keystores.
-    /// The conductor is independent of the specialized implementation of the trait
-    /// PassphraseService. It just needs something to provide a passphrase when needed.
-    /// This config setting selects one of the available services (i.e. CLI prompt, IPC, FromConfig)
-    pub passphrase_service: PassphraseServiceConfig,
-
     /// Setup admin interfaces to control this conductor through a websocket connection
     pub admin_interfaces: Option<Vec<AdminInterfaceConfig>>,
 
@@ -122,9 +109,8 @@ pub mod tests {
         let yaml = r#"---
     environment_path: /path/to/env
 
-    passphrase_service:
-      type: danger_insecure_from_config
-      passphrase: "test-passphrase"
+    keystore:
+      type: danger_test_keystore_legacy_deprecated
     "#;
         let result: ConductorConfig = config_from_yaml(yaml).unwrap();
         assert_eq!(
@@ -133,12 +119,8 @@ pub mod tests {
                 environment_path: PathBuf::from("/path/to/env").into(),
                 network: None,
                 dpki: None,
-                passphrase_service: PassphraseServiceConfig::DangerInsecureFromConfig {
-                    passphrase: "test-passphrase".to_string(),
-                },
-                keystore_path: None,
+                keystore: KeystoreConfig::DangerTestKeystoreLegacyDeprecated,
                 admin_interfaces: None,
-                use_dangerous_test_keystore: false,
                 db_sync_level: DbSyncLevel::default(),
             }
         );
@@ -150,14 +132,13 @@ pub mod tests {
 
         let yaml = r#"---
     environment_path: /path/to/env
-    use_dangerous_test_keystore: true
     signing_service_uri: ws://localhost:9001
     encryption_service_uri: ws://localhost:9002
     decryption_service_uri: ws://localhost:9003
 
-    passphrase_service:
-      type: danger_insecure_from_config
-      passphrase: "test-passphrase"
+    keystore:
+      type: lair_server_legacy_deprecated
+      danger_passphrase_insecure_from_config: "test-passphrase"
 
     dpki:
       instance_id: some_id
@@ -188,7 +169,7 @@ pub mod tests {
         proxy_keepalive_ms: 42
         proxy_to_expire_ms: 42
       network_type: quic_bootstrap
-    
+
     db_sync_level: Off
     "#;
         let result: ConductorConfigResult<ConductorConfig> = config_from_yaml(yaml);
@@ -220,15 +201,14 @@ pub mod tests {
             result.unwrap(),
             ConductorConfig {
                 environment_path: PathBuf::from("/path/to/env").into(),
-                use_dangerous_test_keystore: true,
                 dpki: Some(DpkiConfig {
                     instance_id: "some_id".into(),
                     init_params: "some_params".into()
                 }),
-                passphrase_service: PassphraseServiceConfig::DangerInsecureFromConfig {
-                    passphrase: "test-passphrase".to_string(),
+                keystore: KeystoreConfig::LairServerLegacyDeprecated {
+                    keystore_path: None,
+                    danger_passphrase_insecure_from_config: "test-passphrase".to_string(),
                 },
-                keystore_path: None,
                 admin_interfaces: Some(vec![AdminInterfaceConfig {
                     driver: InterfaceDriver::Websocket { port: 1234 }
                 }]),
@@ -238,16 +218,16 @@ pub mod tests {
         );
     }
 
+    /* TODO uncomment when new_lair_api initialization is implemented
     #[test]
-    fn test_config_keystore() {
+    fn test_config_new_lair_keystore() {
         let yaml = r#"---
     environment_path: /path/to/env
-    use_dangerous_test_keystore: true
     keystore_path: /path/to/keystore
 
-    passphrase_service:
-      type: danger_insecure_from_config
-      passphrase: "foobar"
+    keystore:
+      type: lair_server
+      connection_url: "unix:///var/run/lair-keystore/socket?k=EcRDnP3xDIZ9Rk_1E-egPE0mGZi5CcszeRxVkb2QXXQ"
     "#;
         let result: ConductorConfigResult<ConductorConfig> = config_from_yaml(yaml);
         assert_eq!(
@@ -256,14 +236,13 @@ pub mod tests {
                 environment_path: PathBuf::from("/path/to/env").into(),
                 network: None,
                 dpki: None,
-                passphrase_service: PassphraseServiceConfig::DangerInsecureFromConfig {
-                    passphrase: "foobar".into()
+                keystore: KeystoreConfig::LairServer {
+                    connection_url: url2::url2!("unix:///var/run/lair-keystore/socket?k=EcRDnP3xDIZ9Rk_1E-egPE0mGZi5CcszeRxVkb2QXXQ").into(),
                 },
-                keystore_path: Some(PathBuf::from("/path/to/keystore").into()),
                 admin_interfaces: None,
-                use_dangerous_test_keystore: true,
                 db_sync_level: DbSyncLevel::default(),
             }
         );
     }
+    */
 }
